@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.300100';
+$BalanceOfPower::Commands::VERSION = '0.400000';
 use v5.10;
 use Moo;
 use IO::Prompter [-stdio];
@@ -8,6 +8,7 @@ use BalanceOfPower::Player;
 use BalanceOfPower::Executive;
 use BalanceOfPower::Constants ":all";
 use BalanceOfPower::Utils qw(next_turn prev_turn get_year_turns compare_turns evidence_text);
+use Data::Dumper;
 
 with 'BalanceOfPower::Role::Logger';
 
@@ -121,6 +122,7 @@ sub get_prompt_text
         $prompt_text .= "Controlling $controlled (" . "Int:" . $ctrl_n->production_for_domestic . "    Exp:" . $ctrl_n->production_for_export . "    Prtg:" . $ctrl_n->prestige . "    Army:" . $ctrl_n->army . ")\n";
         $prompt_text .= "Control orders: " .  $player->get_control_order($controlled) . "\n" if $player->get_control_order($controlled);
     }
+    $prompt_text .= "You're in " . $player->position . "\n";
     $prompt_text .= $self->nation ? "(" . $self->nation . " [" . $player->influence($self->nation) .  "]) ?" : "?";
     return $prompt_text;
 }
@@ -759,6 +761,85 @@ sub control_commands
     return $result;
 }
 
+sub travel_commands
+{
+    my $self = shift;
+    my $query = $self->query;
+    my $result = { status => 0 };
+    $query = lc $query;
+    if($query eq "travels")
+    {
+        say $self->get_active_player->print_travel_plan($self->world);  
+        $result = { status => 2 };
+    }
+    elsif($query =~ /^go( (.*))$/)
+    {
+        my $input_nation = $self->world->correct_nation_name($2);
+        my ($status, $info) = $self->get_active_player->go($self->world, $input_nation);
+        if($status != 1)
+        {
+            $result = { status => $status };       
+        }
+        else
+        {
+            $result = { status => 1, travel => $info };
+        }
+    }
+    return $result;
+}
+
+sub shop_commands
+{
+    my $self = shift;
+    my $query = $self->query;
+    my $result = { status => 0 };
+    $query = lc $query;
+    if($query =~ /^prices( (.*))$/)
+    {
+        my $input_nation = $self->world->correct_nation_name($2);
+        if($input_nation)
+        {
+            say $self->world->print_nation_shop_prices($self->world->current_year, $input_nation);
+            $result = { status => 1 }
+        }
+        else
+        {
+            $result = { status => -1 }
+        }
+    }
+    elsif($query eq 'cargo')
+    {
+        say $self->get_active_player->print_cargo();
+        $result = { status => 1 };
+    }
+    elsif($query =~ /^sbuy +([0-9]+) +(.*)$/)
+    {
+        my ($res, $cost) = $self->world->do_transaction($self->get_active_player, 'buy', $1, $2);
+        if($res == 1)
+        {
+            $result = { status => 20, cost => $cost};
+        }
+        else
+        {
+            $result = { status => $res };
+        }
+    }
+    elsif($query =~ /^ssell +([0-9]+) +(.*)$/)
+    {
+        my ($res, $cost) = $self->world->do_transaction($self->get_active_player, 'sell', $1, $2);
+        if($res == 1)
+        {
+            $result = { status => 30, cost => $cost};
+        }
+        else
+        {
+            $result = { status => $res };
+        }
+    }
+    return $result;
+}
+
+
 sub commands
 {
     my $self = shift;
@@ -787,6 +868,18 @@ sub commands
         $self->latest_result($result);
         return 1;
     }
+    $result = $self->travel_commands();
+    if($self->handle_result('travel', $result))
+    {
+        $self->latest_result($result);
+        return 1;
+    }
+    $result = $self->shop_commands();
+    if($self->handle_result('shop', $result))
+    {
+        $self->latest_result($result);
+        return 1;
+    }
     $result = $self->orders();
     if($self->handle_result('orders', $result))
     {
@@ -820,6 +913,8 @@ sub handle_result
     my $self = shift;
     my $type = shift;
     my $result = shift;
+    #say $self->query . " - $type: " . $result->{status};
+    #say Dumper($result);
     if($type eq 'turn')
     {
         if($result->{status} == 1)
@@ -968,6 +1063,81 @@ sub handle_result
             return 0;
         }
     }
+    elsif($type eq 'travel')
+    {
+        if($result->{status} == -1)
+        {
+            say "Route blocked";
+            return 1;
+        }
+        elsif($result->{status} == -2)
+        {
+            say "Not enough movements";
+            return 1;
+        }
+        elsif($result->{status} == -3)
+        {
+            say "Destination unreachable";
+            return 1;
+        }
+        elsif($result->{status} == 1)
+        {
+            say "Moved to " . $result->{travel}->{destination} . " via " . $result->{travel}->{way};
+            say $result->{travel}->{cost} . " movements payed";
+            say "Movements available are now " . $self->get_active_player->movements;
+            print "\n";
+        } 
+        elsif($result->{status} == 2)
+        {
+            return 1;
+        }
+        else
+        {
+            return 0;
+        }
+    }
+    elsif($type eq 'shop')
+    {
+        if($result->{status} == 20)
+        {
+            say "Transaction completed. Payed: " . $result->{cost};
+            return 1;
+        }
+        elsif($result->{status} == 30)
+        {
+            say "Transaction completed. Earned: " . $result->{cost};
+            return 1;
+        }
+        elsif($result->{status} == -1)
+        {
+            say "Bad nation";
+            return 1;
+        }
+        elsif($result->{status} == -10)
+        {
+            say "Bad type of trade";
+            return 1;
+        }
+        elsif($result->{status} == -11)
+        {
+            say "Not enough money";
+            return 1;
+        }
+        elsif($result->{status} == -12)
+        {
+            say "Not enough cargo space";
+            return 1;
+        }
+        if($result->{status} == -13)
+        {
+            say "You don't owe that quantity";
+            return 1;
+        }
+        else
+        {
+            return 0;
+        }
+    }
 }
 
 
