@@ -1,5 +1,5 @@
 package BalanceOfPower::Player;
-$BalanceOfPower::Player::VERSION = '0.300100';
+$BalanceOfPower::Player::VERSION = '0.400000';
 use strict;
 use v5.10;
 
@@ -9,6 +9,8 @@ use BalanceOfPower::Constants ':all';
 with 'BalanceOfPower::Role::Reporter';
 with 'BalanceOfPower::Player::Role::Broker';
 with 'BalanceOfPower::Player::Role::Hitman';
+with 'BalanceOfPower::Player::Role::Traveler';
+with 'BalanceOfPower::Player::Role::Cargo';
 
 
 has name => (
@@ -19,6 +21,7 @@ has current_year => (
     is => 'rw'
 );
 
+
 sub dump
 {
     my $self = shift;
