@@ -1,9 +1,10 @@
 package BalanceOfPower::Role::GameMaster;
-$BalanceOfPower::Role::GameMaster::VERSION = '0.300100';
+$BalanceOfPower::Role::GameMaster::VERSION = '0.400000';
 use strict;
 use v5.10;
 
 use Moo::Role;
+use List::Util qw(shuffle);
 
 use BalanceOfPower::Player;
 use BalanceOfPower::Targets::Fall;
@@ -33,11 +34,24 @@ sub create_player
 {
     my $self = shift;
     my $username = shift;
+    my $position = shift;
+    my $money = shift || START_PLAYER_MONEY;
     my $already = $self->get_player($username);
-    return 0 if($already);
+    if($already)
+    {
+        $already->position($position);
+        $already->money($money);
+        return 0;
+    }
+    if(! $position)
+    {
+        my @nations = @{$self->nation_names};
+        @nations = shuffle @nations;
+        $position = $nations[0];
+    }
     my $log_name = $username . ".log";
     $log_name =~ s/ /_/g;
-    my $pl = BalanceOfPower::Player->new(name => $username, money => START_PLAYER_MONEY, log_name => $log_name, log_dir => $self->log_dir, current_year => $self->current_year);
+    my $pl = BalanceOfPower::Player->new(name => $username, money => $money, log_name => $log_name, log_dir => $self->log_dir, current_year => $self->current_year, position => $position);
     $pl->delete_log();
     $pl->register_event("ENTERING THE GAME");
     $self->register_event("$username IS ENTERING THE GAME");
@@ -67,12 +81,13 @@ sub delete_player
     my @players = grep { $_->name ne $player} @{$self->players};
     $self->players(\@players);
 }
-sub player_current_year
+sub player_start_turn
 {
     my $self = shift;
     for(@{$self->players})
     {
         $_->current_year($self->current_year);
+        $_->refill_movements();
     }
 }
 
