@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::WebMaster;
-$BalanceOfPower::Role::WebMaster::VERSION = '0.300100';
+$BalanceOfPower::Role::WebMaster::VERSION = '0.400000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -40,6 +40,8 @@ requires 'pre_decisions_elaborations';
 requires 'decisions';
 requires 'post_decisions_elaborations';
 requires 'print_market';
+requires 'print_nation_shop_prices';
+requires 'print_all_nations_prices';
 
 
 
@@ -47,6 +49,7 @@ sub build_pre_statics
 {
     my $self = shift;
     my $game = shift;
+    my $year = shift || $self->current_year;
     my $site_root = $self->site_root;
     my $dest_dir = "$site_root/views/generated/$game/" . $self->current_year();
     make_path $dest_dir;
@@ -74,6 +77,9 @@ sub build_pre_statics
     open(my $market, "> $dest_dir/market.tt");
     print {$market} $self->print_market('html');
     close($market);
+    open(my $prices, "> $dest_dir/prices.tt");
+    print {$prices} $self->print_all_nations_prices($year, 'html');
+    close($prices);
     $self->build_nations_statics($game, $site_root);
     $self->build_players_statics($game, $site_root);
 }
@@ -147,6 +153,9 @@ sub build_nations_statics
         open(my $graphs, "> $dest_dir/graphs.tt");
         print {$graphs} $self->print_nation_graphs($nation, prev_turn($self->current_year()), 10, 'html');  
         close($graphs);
+        open(my $prices, "> $dest_dir/prices.tt");
+        print {$prices} $self->print_nation_shop_prices($self->current_year, $nation, 'html');  
+        close($prices);
         $dest_dir = "$site_root/metadata/$game/n";
         make_path($dest_dir);
         open(my $nation_meta, "> $dest_dir/" . $code . ".data");
@@ -175,13 +184,17 @@ sub build_nations_statics
             }
         }
         my $nation_obj = $self->get_nation($nation);
+        my %travels = $self->make_travel_plan($nation);
+        my %prices = $self->get_all_nation_prices($nation, $self->current_year);
         my %nation_hash = ( stocks => $nation_obj->available_stocks,
                             internal_production => $nation_obj->production_for_domestic,
                             export_production => $nation_obj->production_for_export,
                             prestige => $nation_obj->prestige,
                             army => $nation_obj->army,
                             civil_war => $civil_war,
-                            commands => \%command_matrix );
+                            commands => \%command_matrix,
+                            travels => \%travels,
+                            prices => \%prices );
         print {$nation_meta} Dumper(\%nation_hash);
         close($nation_meta);
     }
@@ -301,6 +314,7 @@ sub generate_web_interactive_turn
     $self->decisions();
     $self->post_decisions_elaborations();
     $self->build_post_statics($game, $site_root);
+    $self->update_web_players($game);
     $self->pre_decisions_elaborations(next_turn($self->current_year));
     $self->build_pre_statics($game, $site_root);
 }
@@ -314,7 +328,7 @@ sub manage_web_players
     {
         for(@{$players})
         {
-            $self->create_player($_);
+            $self->create_player($_->{'username'}, $_->{'position'}, $_->{'money'});
         }
     }
 }
@@ -352,6 +366,22 @@ sub manage_influence_orders
     }
 }
 
+sub update_web_players
+{
+    my $self = shift;
+    my $game = shift;
+    my $password = $self->admin_password;
+    my @players = @{$self->players};
+    foreach my $p (@players)
+    {
+        my $res = $self->post_web_data("/api/$game/user-data", { password => $password,
+                                                                 player => $p->name,
+                                                                 money => $p->money,
+                                                                 position => $p->position });
+        say "$game - Updating " . $p->name. ": " . $res;
+    }
+}
+
 sub get_web_data
 {
     my $self = shift;
@@ -379,6 +409,18 @@ sub get_web_data
     }
 }
 
+sub post_web_data
+{
+    my $self = shift;
+    my $call = shift;
+    my $form = shift;
+    my $ua = LWP::UserAgent->new;
+    $ua->timeout(10);
+    $ua->env_proxy;
+    my $response = $ua->post($self->api_url . $call, $form);
+    return $response->code;
+}
+
 1;
 
 
