@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.300100';
+$BalanceOfPower::World::VERSION = '0.400000';
 use strict;
 use v5.10;
 
@@ -95,8 +95,9 @@ with 'BalanceOfPower::Role::Warlord';
 with 'BalanceOfPower::Role::Rebel';
 with 'BalanceOfPower::Role::CrisisManager';
 with 'BalanceOfPower::Role::Analyst';
-with 'BalanceOfPower::Role::WebMaster';
 with 'BalanceOfPower::Role::Recorder';
+with 'BalanceOfPower::Role::Shopper';
+with 'BalanceOfPower::Role::WebMaster';
 
 sub get_nation
 {
@@ -271,7 +272,7 @@ sub pre_decisions_elaborations
     my $t = shift;
     $self->init_year($t);
     $self->war_current_year();
-    $self->player_current_year();
+    $self->player_start_turn();
     $self->civil_war_current_year();
     $self->war_debts();
     $self->crisis_generator();
@@ -345,7 +346,9 @@ sub init_year
         $n->production($prod);
         my $prestige = $self->calculate_prestige($n);
         $n->prestige($prestige);
+        my $pu = PRODUCTION_UNITS->[$n->size];
         $self->set_statistics_value($n, 'production', $prod);
+        $self->set_statistics_value($n, 'p/d', int(($prod / $pu) * 100) / 100);
         $self->set_statistics_value($n, 'debt', $n->debt);
         $self->set_statistics_value($n, 'prestige', $prestige);
     }
@@ -1004,6 +1007,46 @@ sub stipulate_treaty
 
 # TRATIES END ##############################################################
 
+# TRAVELS ##################################################################
+
+sub make_travel_plan
+{
+    my $self = shift;
+    my $from = shift;
+    my @already = ();
+    my %plan;
+    $plan{'ground'} = {};
+    $plan{'air'} = {};
+    my @for_commerce = $self->route_destinations_for_node($from);
+    
+    my @at_borders = $self->near_nations($from, 1);
+    foreach my $n(@for_commerce)
+    {
+        if(! grep { $_ eq $n } @already)
+        {
+            my $youcan = 'OK';
+            $youcan = 'KO' if($self->war_busy($from) || $self->war_busy($n));
+            $plan{'air'}->{$n}->{status} = $youcan;
+            my $cost = $self->distance($from, $n) * AIR_TRAVEL_COST_FOR_DISTANCE;
+            $cost = AIR_TRAVEL_CAP_COST if $cost > AIR_TRAVEL_CAP_COST;
+            $plan{'air'}->{$n}->{cost} = $cost if($youcan eq 'OK');
+            push @already, $n if $youcan eq 'OK';
+        }
+    }
+    foreach my $n(@at_borders)
+    {
+        if(! grep { $_ eq $n } @already)
+        {
+            $plan{'ground'}->{$n}->{status} = 'OK';
+            $plan{'ground'}->{$n}->{cost} = GROUND_TRAVEL_COST;
+            push @already, $n;
+        }
+    }
+    return %plan;
+}
+
+#########################################################################
+
 sub register_global_data
 {
     my $self = shift;
